#
# spec file for package AppStream
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libappstream_sover 4
%define libAppStreamQt_sover 2

Name:           AppStream
Version:        0.11.8
Release:        lp150.1.5
Summary:        Utilities to generate, maintain and access the AppStream Xapian database
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Url:            https://www.freedesktop.org/software/appstream/docs/
Source:         http://www.freedesktop.org/software/appstream/releases/%{name}-%{version}.tar.xz
Patch0:         0001-Fix-regression-from-153.patch
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  meson >= 0.42
BuildRequires:  xmlto
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.46
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(packagekit-glib2)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(xapian-core)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
AppStream-Core makes it easy to access application information from the
AppStream database over a nice GObject-based interface.

%package -n libappstream%{libappstream_sover}
Summary:        The main library for AppStream
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries

%description -n libappstream%{libappstream_sover}
The main library for AppStream.

%package -n libAppStreamQt%{libAppStreamQt_sover}
Summary:        Qt5 bindings for AppStream
License:        GPL-2.0+ and LGPL-2.1+
Group:          System/Libraries

%description -n libAppStreamQt%{libAppStreamQt_sover}
The Qt5 bindings for AppStream.

%package -n libAppStreamQt-devel
Summary:        Needed include files and libraries for development
License:        GPL-2.0+ and LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       libAppStreamQt%{libAppStreamQt_sover} = %{version}
Requires:       libappstream%{libappstream_sover} = %{version}

%description -n libAppStreamQt-devel
This package contains all necessary include files, libraries,
configuration files and development tools (with manual pages) needed to
compile and link applications using the Qt bindings for AppStream.

%package devel
Summary:        Needed include files and libraries for development
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       libappstream%{libappstream_sover} = %{version}

%description devel
This package contains all necessary include files, libraries,
configuration files and development tools (with manual pages) needed to
compile and link applications using AppStream.

%package doc
Summary:        Documentation for AppStream
License:        GPL-2.0+
Group:          Documentation/HTML

%description doc
AppStream-Core makes it easy to access application information from the
AppStream database over a nice GObject-based interface.

This package contains the documentation files for AppStream.

%package -n typelib-1_0-AppStream-1.0
Summary:        Simple software installation management software -- Introspection bindings
License:        LGPL-2.1+
Group:          System/Libraries

%description -n typelib-1_0-AppStream-1.0
PackageKit is a system designed to make installing and updating
software on your computer easier.  The primary design goal is to unify
all the software graphical tools used in different distributions, and
use some of the latest technology like PolicyKit to make the process
suck less.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
%if "%{?_lib}" == "lib64"
SUFFIX="64"
%else
SUFFIX=""
%endif

%meson -Dqt=true \
       -Dvapi=true \
       -Ddocs=false \
       -Dapidocs=false \
       -Dstemming=false
%meson_build

%install
%meson_install

%find_lang appstream %{name}.lang

%post
appstreamcli refresh --force || true

%post -n libappstream%{libappstream_sover} -p /sbin/ldconfig

%postun -n libappstream%{libappstream_sover} -p /sbin/ldconfig

%post -n libAppStreamQt%{libAppStreamQt_sover} -p /sbin/ldconfig

%postun -n libAppStreamQt%{libAppStreamQt_sover} -p /sbin/ldconfig

%files lang -f %{name}.lang

%files
%defattr(-,root,root)
%doc LICENSE* NEWS
%{_bindir}/appstreamcli
%config(noreplace) %{_sysconfdir}/appstream.conf
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/org.freedesktop.appstream.cli.metainfo.xml
%{_mandir}/man1/appstreamcli.*

%files -n libappstream%{libappstream_sover}
%defattr(-,root,root)
%doc LICENSE* NEWS
%{_libdir}/libappstream.so.*

%files -n libAppStreamQt%{libAppStreamQt_sover}
%defattr(-,root,root)
%doc LICENSE*
%{_libdir}/libAppStreamQt.so.*

%files -n libAppStreamQt-devel
%defattr(-,root,root)
%{_includedir}/AppStreamQt/
%{_libdir}/cmake/AppStreamQt/
%{_libdir}/libAppStreamQt.so

%files devel
%defattr(-,root,root)
%{_libdir}/libappstream.so
%{_libdir}/pkgconfig/appstream.pc
%{_includedir}/appstream/
%{_datadir}/gir-1.0/AppStream-1.0.gir
%{_datadir}/gettext/
%dir %{_datadir}/vala/
%dir %{_datadir}/vala/vapi/
%{_datadir}/vala/vapi/appstream.deps
%{_datadir}/vala/vapi/appstream.vapi

%files -n typelib-1_0-AppStream-1.0
%defattr(-,root,root)
%doc LICENSE*
%{_libdir}/girepository-1.0/AppStream-1.0.typelib

%files doc
%defattr(-,root,root)
%{_datadir}/doc/appstream

%changelog
* Mon Jan 29 2018 alarrosa@suse.com
- Now the appstream cache is refreshed in %%post. The update to 0.11.8
  plus the refresh fixes kde#389531.
- Headers are now installed to /usr/include/appstream instead of
  /usr/inlude/AppStream
- New package AppStream-doc with the html documentation for AppStream
- Use meson to build instead of cmake
- Update to version 0.11.8:
  Features:
  * validator: Emit a hint in case a discouraged AppStream ID style is used (Matthias Klumpp)
  * l10n: Renamed Norwegian Bokmål language file (Matthias Klumpp)
  Specification:
  * docs: Add quickstart instructions for intltool (David Steele)
  * spec: Discourage use of hyphens and digit-started segments for IDs (Matthias Klumpp)
  Bugfixes:
  * qt: Export the AppStreamQt target (Aleix Pol)
  * Various string improvements (Allan Nordhøy)
  * validator: Don't make HEAD requests for URL checks, fetch first byte instead (Matthias Klumpp)
  * Enforce a non-broken version of gobject-introspection (Matthias Klumpp)
  * Ensure LINGUAS update is only run explicitly (Matthias Klumpp)
  * Fix a minor memory and fd leak (Matthias Klumpp)
- Update to version 0.11.7:
  Notes:
  * The appstreamcli validation commands now use curl if it is available to check all
    URLs in the metadata for existence.
    If you don't want this behavior, pass "--nonet" to appstreamcli. There might also
    be false positives (one is known with the KDE bugtracker) that need to be investigated,
    so feedback on this new feature is welcome.
  Features:
  * validator: Check all urls for validity (Matthias Klumpp)
  * validator: Check web-application components for missing tags (Matthias Klumpp)
  * Add API to retrieve the AppStream library version (Matthias Klumpp)
  * apt: Allow fetching 128x128@2 HiDPI icons (Rico Tzschichholz)
  Specification:
  * Add the "url" launchable type (Dimitrios Christidis)
  * spec: Clarify some icon details in the collection data (Marius Vollmer)
  * spec: Allow <icon> tags in generic components (Marius Vollmer)
  * spec: Specify the web-application component type (Matthias Klumpp)
  Bugfixes:
  * Fix endless loop when validating screenshots (Matthias Klumpp)
  * ascli: Show a list of component-types when --help is passed to new-template (Matthias Klumpp)
  * validator: Drop the wget fallback, making missing curl only an info (Matthias Klumpp)
  * meson: Properly define header-file in gir (Rico Tzschichholz)
- Update to version 0.11.6:
  Features:
  * Improve screenshot validation (Matthias Klumpp)
  * Allow to disable introspection (Matthias Klumpp)
  Bugfixes:
  * Revert back to the old build option names (Matthias Klumpp)
  * Apply maintainer flags equally to C++ and C (Matthias Klumpp)
  * Explicitly set C/C++ standard versions (Matthias Klumpp)
  * vapi: Include the right header (Matthias Klumpp)
  * xml: Correctly write screenshots tag again (Matthias Klumpp)
  * Do not cache a screenshot that doesn't have images (Matthias Klumpp)
  * xml: Support legacy screenshot tags again (Matthias Klumpp)
- Update to version 0.11.5:
  Features:
  * Restructure build feature flags (Matthias Klumpp)
  * Allow disabling API documentation build (Matthias Klumpp)
  Bugfixes:
  * qt: Don't check bitness when finding AppStreamQt (Matthias Klumpp)
- Update to version 0.11.4:
  Notes:
  * This release switches the build system from CMake to Meson. You will need
    Meson (>= 0.42) in order to build AppStream. Please test for any regressions.
  Features:
  * Implement Meson support (Matthias Klumpp)
  * meson: Make build with sanitizers (partially) work again (Matthias Klumpp)
  * meson: Add helper script for building documentation (Matthias Klumpp)
  * docs: Always rebuild documentation on-demand (Matthias Klumpp)
  * Update README for Meson (Matthias Klumpp)
  * Implement cockpit-manifest launchable type (Matthias Klumpp)
  * validator: Actually validate the type property of "launchable" tags (Matthias Klumpp)
  * Allow to search the pool for components that provide a launchable (Matthias Klumpp)
  * qt: Add new function to search components by launchable (Matthias Klumpp)
  Specification:
  * spec: New "cockpit-manifest" launchable type (Marius Vollmer)
  Bugfixes:
  * validator: Complain if a component has no ID (Matthias Klumpp)
- Update to version 0.11.3:
  Bugfixes:
  * qt: Don't crash when an error is found and no error string is passed (Aleix Pol)
  * Propagate document context to the context object for XML files (Matthias Klumpp)
  * validator: Correctly recognize "launchable" as valid tag (Matthias Klumpp)
- Update to version 0.11.2:
  Features:
  * cache: Refactor cache functions (Matthias Klumpp)
  * Deduplicate origin/locale/arch with AsContext (Matthias Klumpp)
  * Get rid of a couple of internal helper methods (Matthias Klumpp)
  * cli: When using convert, always assume collection style for YAML (Matthias Klumpp)
  Specification:
  * Adjust docs to clearly state that licenses are SPDX expressions (Harald Sitter)
  Bugfixes:
  * qt: Improve Icon QDebug information (Aleix Pol)
  * Resolve crash when serializing lots of XML documents (Matthias Klumpp)
  * xml: Don't truncate translated entries after encounting a wrong locale (Matthias Klumpp)
  * Set a real locale if locale is set to "ALL" (Matthias Klumpp)
  * validator: Make ending dot in component name only a pedantic issue (Matthias Klumpp)
- Add patch to export the AppStreamQt target correctly:
  * 0001-Fix-regression-from-153.patch
* Wed Jul  5 2017 fabian@ritter-vogt.de
- Update to version 0.11.1:
  Notes:
  * This release contains refactoring of the XML/YAML parsers and some other changes that are more invasive
    than usual.
  Features:
  * qt: Add new getters/setters and classes to be on par with the GObject library (Jan Grulich)
  * qt: Add AS::Metadata class used for parsing desktop and appstream metadata files (Jan Grulich)
  * Refactor the XML parser and serialization code (Matthias Klumpp)
  * Refactor the YAML parser and emitter code (Matthias Klumpp)
  * Implement 'service' component type (Matthias Klumpp)
  * Improve speed of metainfo description parsing slightly (Matthias Klumpp)
  * test: Add additional testcase for reading metainfo description tags (Matthias Klumpp)
  * test: Test metainfo descriptions starting with enumerations (Matthias Klumpp)
  Specification:
  * doc: Add Distro Packaging page (Jeremy Bicha)
  * doc: Add "service" components and their launchables (Marius Vollmer)
  * Allow components to provide other components (provides -> id) (Matthias Klumpp)
  Bugfixes:
  * doc: Uncomment line in middle of paragraph (Jeremy Bicha)
  * doc: A releases tag is not essential for components, but summary is (Matthias Klumpp)
  * Allow descriptions to start with an enumeration (Matthias Klumpp)
  * Ensure we always update with fresh data when refreshing the cache (Matthias Klumpp)
  * Replace invalid components in the pool with new ones of the same name (Matthias Klumpp)
  * Resolve a few potential bugs (found by static checks) (Matthias Klumpp)
  * xml: Check if we are trying to parse a real component (Matthias Klumpp)
- Update to version 0.11.0:
  Features:
  * Implement read/write support for content ratings (Matthias Klumpp)
  * tests: Test the content_rating tag XML read/write (Matthias Klumpp)
  * yaml: Read/write ContentRating (Matthias Klumpp)
  * cache: Handle the content-rating property (Matthias Klumpp)
  * Add new AsLaunch type (Matthias Klumpp)
  * Fully implement the launchable tag (Matthias Klumpp)
  * Recognize scaling factor for HiDPI icons (Matthias Klumpp)
  * apt: Allow fetching HiDPI icons (Matthias Klumpp)
  Specification:
  * spec: Don't give wrong information about the <font/> tag (Matthias Klumpp)
  * spec: Specify content_rating tag for content age ratings (Matthias Klumpp)
  * spec: Specify the new launchable tag and apply its effects (Matthias Klumpp)
  * spec: Add note on where to place icons with a scaling factor (Matthias Klumpp)
  Bugfixes:
  * Add missing word in string (Anders Jonsson)
  * yaml: Fix crash when serializing component with a dbus:user provided item (Matthias Klumpp)
  * cache: Don't write cache if there are no valid components (Matthias Klumpp)
  * docs: Clarify "permissive" for metadata_license and make the paragraph more explicit (Matthias Klumpp)
  * Ensure GVFS never starts in root user slice (Matthias Klumpp)
  * Correctly tokenize values with dash or plus (Matthias Klumpp)
  * vapi: Add appstream.deps file (Rico Tzschichholz)
- Update to version 0.10.6:
  Features:
  * validator: Be more strict about the <icon> tag types in metainfo files (Matthias Klumpp)
  * validator: Unconditionally check for name and summary (Matthias Klumpp)
  * Move all merge logic to AsComponent (Matthias Klumpp)
  * Allow making AppStream consume data from metainfo instead of collection files (Matthias Klumpp)
  * apt: Do not enable any icon downloads by default (Matthias Klumpp)
  * validator: Check categories in XML as well (Matthias Klumpp)
  * cli: Make templates for different component-types a bit more useful (Matthias Klumpp)
  * Allow a few more permissive licenses for metadata_license (Matthias Klumpp)
  * Add support for "+" operator at the end of SPDX license identifiers (Kalev Lember, Matthias Klumpp)
  * cli: Print tiny summary after validation (very useful for validate-tree) (Matthias Klumpp)
  * validator: Validate for hyperlinks in description / summary / developer-name (Matthias Klumpp)
  * validator: Make missing long description a pedantic issue in more cases (Matthias Klumpp)
  * Also recognize "FSFUL" license as pemissive (Matthias Klumpp)
  * validator: Adjust priorities of missing modalias/font tags in driver/font components (Matthias Klumpp)
  * Skip loading desktop-entries if we know their component already (Matthias Klumpp)
  * Be lazier, only parse what is necessary in the data pool (Matthias Klumpp)
  Specification:
  * spec: Clarify that name/summary are now always required for metainfo files (Matthias Klumpp)
  * spec: Clarify desktop vs. desktop-application (Matthias Klumpp)
  * spec: Add a small paragraph about whether and what xmlns to use (Matthias Klumpp)
  * spec: Make it clear <categories/> can be used in metainfo files too (Matthias Klumpp)
  * spec: Make clear that update_contact's value is case-insensitive (Matthias Klumpp)
  * docs: Make sure all examples follow the reverse-DNS scheme (Matthias Klumpp)
  Bugfixes:
  * Don't hardcode share dir but use CMAKE_INSTALL.. (Heiko Becker)
  * validator: Don't enforce .desktop suffix on desktop-app component IDs (Matthias Klumpp)
  * qt: Allow catching error strings returned by Pool::load (Aleix Pol)
  * Always drop data from desktop-entry files if we have better metadata (Matthias Klumpp)
  * apt: Install icons back if they went completely missing (Matthias Klumpp)
  * Update SPDX and TLD data (Matthias Klumpp)
  * yaml: Read release/urgency key (Matthias Klumpp)
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to version 0.10.5:
  Features:
  * Match modalias wildcards on regular searches (Matthias Klumpp)
  * xml: Add methods to get/set custom data in metainfo/collection files (Matthias Klumpp)
  * Make cache update issue messages slightly more verbose (Matthias Klumpp)
  * Add preliminary code for reading metainfo files in addition to .desktop files (Matthias Klumpp)
  * cache: Cache custom fields as well (Matthias Klumpp)
  Bugfixes:
  * qt: Make sure dependencies are fetched when looking for the package (Aleix Pol)
  * yaml: Consistently read/write the Suggests field (Matthias Klumpp)
  * Correctly read bundle kind from XML data (Matthias Klumpp)
- Update to version 0.10.4:
  Features:
  * qt: Introduce AppStream::Suggested in the Qt frontend (Aleix Pol)
  Bugfixes:
  * Properly validate suggests tag (Matthias Klumpp)
  * qt: Add an empty check to Provided and return it if necessary (Matthias Klumpp)
  * Add path search to find libstemmer headers (#91) (Neal Gompa)
- Update to version 0.10.3:
  Notes:
  * The release breaks the Qt library API. Patches to make KDE Discover use the new API exist
    in its Git master branch, and will be available with Plasma 5.9.
    The patches will likely not enter the stable branch, so if you want to upgrade AppStream,
    you might need to ship patches for Discover downstream to use the new API.
  Features:
  * qt: Update API to reflect more recent AppStream features, be easier to
    extend and also a bit faster due to removing needless data conversions.
    (Matthias Klumpp, Aleix Pol)
  * Make components record their origin kind internally (Matthias Klumpp)
  * Provide a file:/ URL for icons when we know a file name (Matthias Klumpp)
  * Add support for Snappy/Snap bundles (Matthias Klumpp)
  Specification:
  * Add new AppStream logo and button (Ken Vermette)
  * Add new AppStream logo and buttons to the docs (Matthias Klumpp)
  Bugfixes:
  * ascli: When converting, always include all translations (Matthias Klumpp)
  * Match .desktop files and metainfo data properly if ID is lacking .desktop suffix (Matthias Klumpp)
- Update to version 0.10.2:
  Features:
  * test: Add unittests for reading urls (Matthias Klumpp)
  * qt: Add AppStream::Category class (Matthias Klumpp)
  * qt: Add missing URL type (Matthias Klumpp)
  * Handle "font" provided type in XML and YAML (Matthias Klumpp)
  * Replace Intltool with modern Gettext/Itstool (Matthias Klumpp)
  * Add logic to parse desktop entries (Matthias Klumpp)
  * Don't add ignored components to the pool (Matthias Klumpp)
  * validator: Validate fd.o domain name, make GNOME warning only pedantic (Matthias Klumpp)
  * validator: Allow languages tag in metainfo files (Matthias Klumpp)
  * Read information from .desktop files and add it to the pool (Matthias Klumpp)
  * Give the client app full control on what data sources we load (Matthias Klumpp)
  * Add private API for component scoping (Matthias Klumpp)
  Specification:
  * docs: Clarify name/summary essentialness for desktop-apps (Matthias Klumpp)
  * spec: Clarify how fonts provides should be handled (Matthias Klumpp)
  * spec: Simplify font metainfo, add more examples and clarify requirements (Matthias Klumpp)
  Bugfixes:
  * ascli: Replace refresh-index with refresh-cache in help text (#81) (Larry Price)
  * qt: nullptr access on unopened databases resulting in a crash (Harald Sitter)
  * qt: The data pool must always be valid during the Database lifetime (Matthias Klumpp)
  * If search results are going to be sorted, it makes sense for higher scores to be at the top of the list. Fixes #77. (Larry Price)
  * validator: Don't enforce long descriptions on fonts (Matthias Klumpp)
  * Hardcode metainfo directory (Matthias Klumpp)
  * ascli: Make every module use the global no-color flag properly (Matthias Klumpp)
  * validator: Don't emit excess warnings on missing type properties (Matthias Klumpp)
- Update to version 0.10.1:
  Features:
  * Add AppStream button image (Ken Vermette)
  * Ship a metainfo file (Matthias Klumpp)
  * Don't use an extra hash table for AsProvided (Matthias Klumpp)
  * Register bundle type for AppImageKit (Matthias Klumpp)
  * Implement localization component type (Matthias Klumpp)
  * validator: Complain less-loudly when encontering GNOME-specific tags (Matthias Klumpp)
  * validator: Check for superfluous dots (Matthias Klumpp)
  * validator: Strictly validate ID for KDE and GNOME (Matthias Klumpp)
  * ascli: Modernize the way we handle subcommands (Matthias Klumpp)
  * qt: Allow retrieving the desktop-id of a component (Matthias Klumpp)
  Specification:
  * Add new driver component type (Matthias Klumpp)
  * spec: Describe localization component type (Matthias Klumpp)
  Bugfixes:
  * docs: Add a few missing classes to the API docs (Matthias Klumpp)
  * Fix cache (de)serialization for screenshots and suggestions (Matthias Klumpp)
  * yaml: Set screenshot image type correctly (Matthias Klumpp)
  * cache: Iterate the right dictionary when looking at checksums (#71) (Iain Lane)
  * apt: Ignore broken symlinks in /var/lib/apt/lists (Iain Lane)
  * as_get_yml_data_origin: Error out if opening the file fails for any reason (Iain Lane)
  * Make addons find their target component again (Matthias Klumpp)
  * yaml: Don't fail if we encounter a translated node without template (Matthias Klumpp)
  * Don't  use GObject ref on GPtrArray (Matthias Klumpp)
  * ascli: Read metainfo files correctly when converting files (Matthias Klumpp)
  * xml: Properly serialize provides tag (Matthias Klumpp)
  * pool: Correctly update addon info when loading data from a cache object (Matthias Klumpp)
  * ascli: Auto-disable colors if we are not on a tty (Matthias Klumpp)
  * yaml: Enforce string/int type on YAML scalars (Matthias Klumpp)
  * yaml: Fix loading of cached icons in all formats (Matthias Klumpp)
  * qt: Never lie about a component kind (Matthias Klumpp)
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use a define for the so version and fix -devel requiring the old libappstream3
* Fri Sep 16 2016 alarrosa@suse.com
- Update to version 0.10.0
- Disable stemming support until we have libstemmer packaged.
- Generate libappstream4 packages since AppStream changes the ABI in 0.10.0
  Notes:
  * This release breaks API/ABI in order to support multiple metadata sets describing the same
  component (needed for bundling support), moving away from the database as central data store
  and general cleanup.
  * Porting is relatively straightforward, if you were using AsDatabase, you should switch to AsPool
  now (AsDatabase has been a wrapper around AsPool for a while anyway).
  * Many methods became private API with this release, file a bug if you miss anything.
  * The 'categories.xml' file is gone - please account for that if you were reading it directly,
  and consider using AsCategory instead, which offers the same functionality.
  Features:
  * Remove the AsDatabase class (Matthias Klumpp)
  * Use cmakedefine for compile-time features (Matthias Klumpp)
  * Rename AsDataPool -> AsPool (Matthias Klumpp)
  * Add placeholder enum for web applications (Matthias Klumpp)
  * qt: Implement Appstream::Release for the Qt interface (Aleix Pol)
  * Recognize the "Pantheon" desktop for Elementary (Matthias Klumpp)
  * Get rid of the menu parser and make AsCategory more useful instead (Matthias Klumpp)
  * Allow AsComponent to automatically check for list-value duplicates (Matthias Klumpp)
  * Give bundles their own class (Matthias Klumpp)
  * Stop shipping the categories.xml file (Matthias Klumpp)
  * Allow multiple metadata sets in the pool to describe a component (Matthias Klumpp)
  * Name AppStream metadata styles consistently (Matthias Klumpp)
  * Allow the 'C' description fallback to be turned off (Iain Lane)
  * Make AsScreenshot return localized images by default (Matthias Klumpp)
  * Allow to compare AsRelease versions easily (Matthias Klumpp)
  * Make get_icon_repository_paths private API (Matthias Klumpp)
  * ascli: Allow dumping metadata as YAML (Matthias Klumpp)
  * Use GVariant instead of ProtoBuf based cache (Matthias Klumpp)
  * Enable stemming by default (Matthias Klumpp)
  * Make components directly reference their addons, avoiding to query twice (Matthias Klumpp)
  * Refactor data pool metadata loading (Matthias Klumpp)
  * Allow setting the AppStream format version when (de)serializing data (Matthias Klumpp)
  * Always write modern metadata, unless a lower format version is requested explicitly (Matthias Klumpp)
  * Also find components in searches which have the search keyword in an addon (Matthias Klumpp)
  * ascli: Add function to convert XML to YAML and vice versa (Matthias Klumpp)
  * Consistent naming for metadata format and style (Matthias Klumpp)
  Specification:
  * spec: Add hint on how the keywords tag should be localized (Matthias Klumpp)
  Bugfixes:
  * Resolve unit test failures on arm and mips (Matthias Klumpp)
  * gir: Correctly annotate ownership transference of GPtrArrays (Matthias Klumpp)
  * l10n: Drop languages without translations (Matthias Klumpp)
  * Don't hide symbols in public headers (Matthias Klumpp)
  * Properly validate desktop-environment strings (Matthias Klumpp)
  * validator: Fix name/summary check in validate-tree (Matthias Klumpp)
  * xml: Properly write localized keywords (Matthias Klumpp)
  * Avoid watching superfluous directories for metadata (Matthias Klumpp)
  * Update architecture diagrams and optimize PNGs (Matthias Klumpp)
  * Get rid of Xapian-isms (Matthias Klumpp)
* Fri Sep 16 2016 alarrosa@suse.com
- Update to version 0.9.8
  Features:
  * qt: Different approach for storing the icon size and url relation (Aleix Pol)
  * Strictly validate AppStream IDs (Matthias Klumpp)
  * Add AsSuggested class (Lucas Moura)
  * tests: Test merges for suggestions (Lucas Moura)
  * Add functions handling SPDX license ids and expressions (Matthias Klumpp)
  * validator: Include a line-hint in the issue report (Matthias Klumpp)
  * Implement console-application component type (Matthias Klumpp)
  * validator: Validate files following the new cid scheme properly (Matthias Klumpp)
  * validator: Validate metadata_license for permissiveness (Matthias Klumpp)
  * Compress cache data (Matthias Klumpp)
  * Implement "translate" URL type (Matthias Klumpp)
  * xml: Implement the suggests tag (Matthias Klumpp)
  * yaml: Implement reading and writing of Suggests field (Matthias Klumpp)
  * Consider merge components valid if they have at least an ID (Matthias Klumpp)
  * yaml: Read/write merge components (Matthias Klumpp)
  Specification:
  * spec: Add console-application component type (Matthias Klumpp)
  * spec: Streamline the requirements for component-ids (Matthias Klumpp)
  * spec: Define a "translate" URL type (Matthias Klumpp)
  * spec: Specify the suggests tag (Matthias Klumpp)
  * spec: Describe the merge property (Matthias Klumpp)
  * spec: Proofreading fixes (Philip Withnall)
  Bugfixes:
  * Make searching for multiple terms work properly again (Matthias Klumpp)
  * Don't fail on invalid search terms (Matthias Klumpp)
  * Don't re-instantiate stemmer on each use (Matthias Klumpp)
  * ascli: Line-wrap unicode texts properly on the console (Matthias Klumpp)
  * Add missing docs to the API reference (Matthias Klumpp)
  * tests: Add test description to each test (Matthias Klumpp)
  * Sort search results by default (Matthias Klumpp)
  * Fix a few issues with merging (Matthias Klumpp)
- From version 0.9.7
  Features:
  * Don't fall back to Debian screenshots server if none is specified for the distro (Matthias Klumpp)
  * Split out distro-specific helpers (Matthias Klumpp)
  * Implement Xapian-less search (Matthias Klumpp)
  * Use a pure PB cache instead of Xapian (Matthias Klumpp)
  * qt: Don't rely on Xapian for searches (Matthias Klumpp)
  * Deprecate AsDatabase (Matthias Klumpp)
  * Hide internal symbols from the symbols table (Matthias Klumpp)
  * Allow injecting components into the pool and unittest the cache (Matthias Klumpp)
  * Add by-category filter to AsDataPool (Matthias Klumpp)
  * Validate Freedesktop category names (Matthias Klumpp)
  * Allow building AppStream with stemming support (Matthias Klumpp)
  * Cache search tokens (Matthias Klumpp)
  Specification:
  * docs/quickstart: Clarify the role of releases/provides (Matthias Klumpp)
  * docs/quickstart: Screenshot images don't need to define width/height (Matthias Klumpp)
  Bugfixes:
  * qt: Properly expose enums for introspection (Aleix Pol)
  * qt: Make it possible to easily output data types using QDebug (Aleix Pol)
  * xml: Fix formatting of <screenshot/> tag (Matthias Klumpp)
  * xml: Work around non-threadsafe behavior of libxml2 (Matthias Klumpp)
  * xml: Properly write provides tag (Matthias Klumpp)
  * Fix code documentation for as_component_get_id (Lucas Moura)
  * Fix some xmldata methods documentation (Lucas Moura)
  * cli: Create metainfo directory if it is missing and respect DESTDIR (Matthias Klumpp)
* Thu Jun  9 2016 mailaender@opensuse.org
- Update to version 0.9.6
  Features:
  * Improve metadata file decompression code (Matthias Klumpp)
  * validator: Simplify loading of data too (Matthias Klumpp)
  * Make it easy to compile with Address Sanitizer enabled (Matthias Klumpp)
  * Allow compiling with UBSan as well (Matthias Klumpp)
  * Add back support for Travis CI (Matthias Klumpp)
  * yaml: Write Releases field (Matthias Klumpp)
  Bugfixes:
  * qt: Properly check for component validity (Matthias Klumpp)
  * Ensure decompressed metadata is null-terminated (Neil Mayhew)
  * validator: Long descriptions are not needed for generic components
  (Matthias Klumpp)
  * Make VAPI generation depend on GIR typelibs explicitly (Matthias Klumpp)
  * Be more verbose when failing to move the cache directory (Matthias Klumpp)
  * Handle format errors when parsing YAML metadata (Neil Mayhew)
* Wed May 18 2016 tittiatcoke@gmail.com
- Drop the separate Vala package and include the files into the
  devel package
* Sun May  8 2016 jengelh@inai.de
- Drop unnecessary manual library require
- Avoid /bin/sh invocation for simple ldconfig calls
* Fri May  6 2016 mailaender@opensuse.org
- Generate the Vala API
- Update to version 0.9.5
  Features:
  * Update README (Matthias Klumpp)
  * Provide a bit more hints for translators (Matthias Klumpp)
  * Improve error messages when reading broken XML (Matthias Klumpp)
  * Load all XML in AsXMLData (Matthias Klumpp)
  * Implement reading localized images from metadata (Matthias Klumpp)
  * Write localized images in XML/YAML serialize routines (Matthias Klumpp)
  * Unify codepaths for checking compatible locales (Matthias Klumpp)
  * yaml: Implement read/write support for the Languages field (Matthias Klumpp)
  * xml: Serialize and read languages tag properly (Matthias Klumpp)
  * validator: Validate files in legacy paths too (Matthias Klumpp)
  Specification:
  * spec: Allow localized screenshot images (Matthias Klumpp)
  Bugfixes:
  * Refactor icon-finding code and fix rare double-free corruption
  (Matthias Klumpp)
  * Properly validate randomly ordered XML tags for duplicates (Matthias Klumpp)
  * validator: The translation tag is only valid in metainfo files
  (Matthias Klumpp)
  * Be slightly less pedantic about size info when reading screenshot
  images (Matthias Klumpp)
  * xml: Properly write <release/> description tag (Matthias Klumpp)
- From version 0.9.4
  Features:
  * Handle legacy screenshot tags (Matthias Klumpp)
  * Print prettier YAML documents (Matthias Klumpp)
  * yaml: Allow loading of distro metadata slices without header
  (Matthias Klumpp)
  * Do not check for installation candidate on minimal validation
  (Matthias Klumpp)
  * Don't check if component has an installation candidate before
  including it (Matthias Klumpp)
  * Quick-check components only when the pool is fully loaded (Matthias Klumpp)
  * Support the stub data of GNOME Software (Matthias Klumpp)
  * Support reading per-component priorities (Matthias Klumpp)
  * Implement the architecture property (Matthias Klumpp)
  * Use architecture data to resolve conflicting IDs (Matthias Klumpp)
  * Add icon size information to generated XML (Matthias Klumpp)
  * xml: Load size hints for icons (Matthias Klumpp)
  * l10n: Update
  Specification:
  * docs: Explicitly define more minimally required tags per component
  type (Matthias Klumpp)
  * Make /usr/share/metainfo the canonical path for upstream metadata
  (Matthias Klumpp)
  * spec: Make architecture a property of <components/>, and no tag
  (Matthias Klumpp)
  * spec: Update the cached icon DEP-11 specification to allow size
  information (Matthias Klumpp)
  Bugfixes:
  * Fix a few minor issues spotted by the YAML validator (Matthias Klumpp)
  * Correctly build distro XML descriptions from upstream XML (Matthias Klumpp)
  * Be very strict about which elements are allowed in a description
  tag (Matthias Klumpp)
  * yaml: Prevent bool keys (Matthias Klumpp)
  * ascli: Properly print long descriptions and wrap lines (Matthias Klumpp)
  * Export less C++ symbols (Matthias Klumpp)
  * Show a better error message when failing to parse XML (Matthias Klumpp)
  * Allow adding 0x0 icons (Matthias Klumpp)
  * yaml: Implement the updated "cached" icon format in a
  backwards-compatible way (Matthias Klumpp)
  * apt: Drop flat repository entries (Matthias Klumpp)
  * Probe less sizes if we already have size information (Matthias Klumpp)
  * Don't make stubs delete package information from valid components
  (Matthias Klumpp)
  * apt: Handle quoted origin entries properly (Matthias Klumpp)
- From version 0.9.3
  Features:
  * Allow to update an existing component with fresh metadata
  * Implement YAML serialization
  * writer: Allow to omit writing a header/root node
  * cli: Add convenience method to install metainfo files
  * cli: Add a new "status" command for various diagnostic information
  * yaml: Allow unicode
  * Print prettier XML by default
  * l10n: Update
  Bugfixes:
  * Reset umask before building the data cache
  * apt: Work around APT using server mtime for its downloaded files
* Mon Feb 29 2016 tittiatcoke@gmail.com
- Update to version 0.9.2
  Features:
  * qt: Improve usage of Qt containers (Aleix Pol)
  * qt: Implement Component::extends on the Qt front-end (Aleix Pol)
  * qt: Also call reserve for bundles on the Qt frontend (Aleix Pol)
  * validator: strstrip values when reading XML/YAML and validate
    linebreaks in summaries (Matthias Klumpp)
  * validator: Check if a description is present (Matthias Klumpp)
  * Always build with YAML support (Matthias Klumpp)
  * Move XML parser into its own class (Matthias Klumpp)
  * Make data-pool use the new YAML-aware metadata parser (Matthias Klumpp)
  * Simplify data-pool building routine (Matthias Klumpp)
  * Preprocess extension information for frontends (Matthias Klumpp)
  * qt: Use the new extensions property (Matthias Klumpp)
  * Implement translations tag (Matthias Klumpp)
  * cli: Document the "install" command (Matthias Klumpp)
  * l10n: Update
  Specification:
  * spec: Document the translation tag (Matthias Klumpp)
  * doc: Don't use <tip/> tags in documentation (Matthias Klumpp)
  * spec: Mention the essential tags for a type:desktop component (Matthias Klumpp)
  Bugfixes:
  * as-cache-builder: Cope with no YAML documents (Iain Lane)
  * 50appstream: Don't run if we can't write to the system paths (Iain Lane)
  * Check for writability instead of root permissions when updating the cache (Matthias Klumpp)
  * qt: Don't compute screenshot images and then forget about them (Aleix Pol)
  * Add the missing extends property to the Xapian cache (Matthias Klumpp)
  * validator: Don't fail validation for description-less addons. (Matthias Klumpp)
  * Make reading empty cache values more robust (Matthias Klumpp)
  * Check if GIR scanner & compiler are really installed (Matthias Klumpp)
* Fri Feb  5 2016 tittiatcoke@gmail.com
- Update to version 0.9.1
  * Improved Qt5 usage
  * Implement date property on release tags
  * Ship ITS files from KDE upstream
- From version 0.9.0
  * Refactor icon handling
  * Modernize AppStream classes
  * Update translations
  * Drop AsSearchQuery
  * Improve error handling for database queries
* Tue Mar 31 2015 hrvoje.senjan@gmail.com
- Activate appstream-qt5 package
